=======
History
=======

0.0.3 (2018-02-10)

* Add more contributors
* Add json to manifest to make it actually work (thanks @martinmaillard)

0.0.1 (2018-02-10)
------------------

* First release on PyPI.
